<?php

require "../connect.php";

// Check if request method is POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve input data
    $name = $_POST["name"];
    $price = $_POST["price"];

    // Validate input data
    if (!empty($name) && is_numeric($price) && $price >= 0) {
        // Prepare SELECT statement to retrieve id based on name
        $select_query = "SELECT id FROM expenses WHERE name = ?";
        $stmt = mysqli_prepare($con, $select_query);

        // Bind parameters to the prepared statement
        mysqli_stmt_bind_param($stmt, "s", $name);

        // Execute the statement
        if (mysqli_stmt_execute($stmt)) {
            // Bind result variables
            mysqli_stmt_bind_result($stmt, $expense_id);

            // Fetch the result (assuming name is unique, should return exactly one row)
            if (mysqli_stmt_fetch($stmt)) {
                // Prepare the UPDATE statement
                $update_query = "UPDATE expenses SET price = ? WHERE id = ?";
                $update_stmt = mysqli_prepare($con, $update_query);

                // Bind parameters to the prepared statement for update
                mysqli_stmt_bind_param($update_stmt, "di", $price, $expense_id);

                // Execute the update statement
                if (mysqli_stmt_execute($update_stmt)) {
                    // Check if any rows were affected
                    if (mysqli_stmt_affected_rows($update_stmt) > 0) {
                        // Success response
                        $response['success'] = true;
                        $response['message'] = "Expense updated successfully";
                    } else {
                        // No rows affected, possibly expense ID not found
                        $response['success'] = false;
                        $response['message'] = "Expense ID not found";
                    }
                } else {
                    // Error response
                    $response['success'] = false;
                    $response['message'] = "Error updating expense: " . mysqli_stmt_error($update_stmt);
                }

                // Close update statement
                mysqli_stmt_close($update_stmt);
            } else {
                // No records found for the provided name
                $response['success'] = false;
                $response['message'] = "Expense not found with the provided name";
            }
        } else {
            // Error response
            $response['success'] = false;
            $response['message'] = "Error fetching expense ID: " . mysqli_stmt_error($stmt);
        }

        // Close select statement
        mysqli_stmt_close($stmt);
    } else {
        // Invalid input response
        $response['success'] = false;
        $response['message'] = "Invalid input data";
    }
} else {
    // Invalid request method response
    $response['success'] = false;
    $response['message'] = "Invalid request method";
}

// Return JSON response
echo json_encode($response);

// Close database connection
mysqli_close($con);

?>

