<?php
require "../connect.php";

// Initialize response array
$flag['success'] = 0;
$flag['data'] = array();
$store_id = $_GET['store_id'] ?? '';

if (empty($store_id)) {
    $flag['success'] = false;
    $flag['message'] = 'Error: Missing store_id parameter';
    echo json_encode($flag);
    exit;
}

// Prepare and execute the select query
$select_query = "SELECT name, quantity, unit_price, total_price, mode_of_payment, created_at FROM sales WHERE store_id = ?";
$stmt = mysqli_prepare($con, $select_query);

if ($stmt) {
    mysqli_stmt_bind_param($stmt, "s", $store_id);
    if (mysqli_stmt_execute($stmt)) {
        mysqli_stmt_store_result($stmt);
        mysqli_stmt_bind_result($stmt, $name, $quantity, $unit_price, $total_price, $mode_of_payment, $created_at);
        $flag['success'] = 1;
        // Fetch results and store in response array
        while (mysqli_stmt_fetch($stmt)) {
            // Format the created_at timestamp to display date only (YYYY-MM-DD)
            $formatted_created_at = date('Y-m-d', strtotime($created_at));

            // Create sales item array with formatted created_at
            $sales_item = array(
                'name' => $name,
                'quantity' => $quantity,
                'unit_price' => $unit_price,
                'total_price' => $total_price,
                'mode_of_payment' => $mode_of_payment,
                'created_at' => $formatted_created_at
            );

            // Add sales item to data array
            $flag['data'][] = $sales_item;
        }
    } else {
        // If prepared statement execution failed, set error message
        $flag['message'] = "Error: " . mysqli_stmt_error($stmt);
    }

    // Close statement
    mysqli_stmt_close($stmt);
} else {
    // If prepared statement creation failed, set error message
    $flag['message'] = "Error: " . mysqli_error($con);
}

// Send response as JSON
echo json_encode($flag);

// Close database connection
mysqli_close($con);
?>





