<?php
require "../connect.php";

// Initialize response array
$flag['success'] = 0;
$flag['data'] = array();

// Check if store_id parameter is provided
if (!isset($_GET['store_id'])) {
    $flag['success'] = 0;
    $flag['message'] = 'Error: Missing store_id parameter';
    echo json_encode($flag);
    exit;
}

// Get the store_id from the URL parameter
$store_id = $_GET['store_id'];

// Prepare and execute the select query
$select_query = "SELECT name, description, quantity, b_price, s_price, created_at FROM stock WHERE store_id = ?";
$stmt = mysqli_prepare($con, $select_query);

if ($stmt) {
    // Bind the store_id parameter to the prepared statement
    mysqli_stmt_bind_param($stmt, "s", $store_id);
    
    // Execute the query
    mysqli_stmt_execute($stmt);
    
    // Bind result variables
    mysqli_stmt_bind_result($stmt, $name, $description, $quantity, $b_price, $s_price, $created_at);
    
    // Fetch results and store in response array
    while (mysqli_stmt_fetch($stmt)) {
        // Format the created_at timestamp to display date only (YYYY-MM-DD)
        $formatted_created_at = date('Y-m-d', strtotime($created_at));
        
        // Create stock item array with formatted created_at
        $stock_item = array(
            'name' => $name,
            'description' => $description,
            'quantity' => $quantity,
            'b_price' => $b_price,
            's_price' => $s_price,
            'created_at' => $formatted_created_at
        );
        
        // Add stock item to data array
        $flag['data'][] = $stock_item;
    }
    
    // Set success flag
    $flag['success'] = 1;
    
    // Close statement
    mysqli_stmt_close($stmt);
} else {
    // If prepared statement creation failed, set error message
    $flag['message'] = "Error: " . mysqli_error($con);
}

// Send response as JSON
echo json_encode($flag);

// Close database connection
mysqli_close($con);

?>


