<?php
require "../connect.php";

$flag['success'] = 0;
$flag['message'] = '';

// Retrieve parameters from POST request
$user_id = $_POST['user_id'] ?? '';
$store_id = $_POST['store_id'] ?? '';
$product_name = $_POST['product_name'] ?? '';
$description = $_POST['description'] ?? '';
$quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
$min_quantity = isset($_POST['min_quantity']) ? intval($_POST['min_quantity']) : 0;
$buying_price = isset($_POST['buying_price']) ? floatval($_POST['buying_price']) : 0.0;
$selling_price = isset($_POST['selling_price']) ? floatval($_POST['selling_price']) : 0.0;

// Validate required parameters
if (empty($user_id)) {
    $flag['message'] = "Missing or invalid parameter: user_id";
    echo json_encode($flag);
    exit;
}
if (empty($store_id)) {
    $flag['message'] = "Missing or invalid parameter: store_id";
    echo json_encode($flag);
    exit;
}
if (empty($product_name)) {
    $flag['message'] = "Missing or invalid parameter: product_name";
    echo json_encode($flag);
    exit;
}
if (empty($description)) {
    $flag['message'] = "Missing or invalid parameter: description";
    echo json_encode($flag);
    exit;
}
if ($quantity === null || $quantity <= 0) {
    $flag['message'] = "Missing or invalid parameter: quantity";
    echo json_encode($flag);
    exit;
}
if ($buying_price === null || $buying_price <= 0.0) {
    $flag['message'] = "Missing or invalid parameter: buying_price";
    echo json_encode($flag);
    exit;
}
if ($selling_price === null || $selling_price <= 0.0) {
    $flag['message'] = "Missing or invalid parameter: selling_price";
    echo json_encode($flag);
    exit;
}


// Check if product already exists
$select_query = "SELECT quantity FROM stock WHERE user_id = ? AND store_id = ? AND name = ? AND description = ?";
$select_statement = mysqli_prepare($con, $select_query);

if ($select_statement) {
    // Bind parameters to the prepared statement
    mysqli_stmt_bind_param($select_statement, "ssss", $user_id, $store_id, $product_name, $description);

    // Execute the prepared statement
    mysqli_stmt_execute($select_statement);

    // Store result
    mysqli_stmt_store_result($select_statement);

    // Check if product already exists in the database
    if (mysqli_stmt_num_rows($select_statement) > 0) {
        // Product already exists, update quantity
        mysqli_stmt_bind_result($select_statement, $existing_quantity);
        mysqli_stmt_fetch($select_statement);

        $new_quantity = $existing_quantity + $quantity;

        // Update quantity for the existing product
        $update_query = "UPDATE stock SET quantity = ? WHERE user_id = ? AND store_id = ? AND name = ? AND description = ?";
       $update_statement = mysqli_prepare($con, $update_query);

        if ($update_statement) {
            // Bind parameters to the prepared statement
            mysqli_stmt_bind_param($update_statement, "issss", $new_quantity, $user_id, $store_id, $product_name, $description);

            // Execute the prepared statement
            if (mysqli_stmt_execute($update_statement)) {
                $flag['success'] = 1;
                $flag['message'] = "Quantity updated successfully";
            } else {
                $flag['message'] = "Error updating quantity: " . mysqli_stmt_error($update_statement);
            }

            // Close the prepared statement
            mysqli_stmt_close($update_statement);
        } else {
            $flag['message'] = "Failed to prepare update statement: " . mysqli_error($con);
        }
    } else {
        // Product does not exist, insert new stock record
        $insert_query = "INSERT INTO stock (user_id, store_id, name, description, quantity, min_quantity, b_price, s_price) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
        $insert_statement = mysqli_prepare($con, $insert_query);

        if ($insert_statement) {
            // Bind parameters to the prepared statement
            mysqli_stmt_bind_param($insert_statement, "ssssiidd", $user_id, $store_id, $product_name, $description, $quantity, $min_quantity, $buying_price, $selling_price);

            // Execute the prepared statement
            if (mysqli_stmt_execute($insert_statement)) {
                $flag['success'] = 1;
                $flag['message'] = "Stock recorded successfully";
            } else {
                $flag['message'] = "Error executing SQL statement: " . mysqli_stmt_error($insert_statement);
            }

            // Close the prepared statement
            mysqli_stmt_close($insert_statement);
        } else {
            $flag['message'] = "Failed to prepare insert statement: " . mysqli_error($con);
        }
    }

    // Close the prepared statement
    mysqli_stmt_close($select_statement);
} else {
    $flag['message'] = "Failed to prepare select statement: " . mysqli_error($con);
}

// Send response as JSON
echo json_encode($flag);

// Close database connection
mysqli_close($con);
?>








