<?php
require "../connect.php";

$flag = array('success' => 0, 'message' => '');

$username = isset($_POST['username']) ? $_POST['username'] : '';
$email = isset($_POST['email']) ? $_POST['email'] : '';
$business_name = isset($_POST['business_name']) ? $_POST['business_name'] : '';
$role = isset($_POST['role']) ? $_POST['role'] : '';
$password = isset($_POST['password']) ? $_POST['password'] : '';
$confirm_password = isset($_POST['confirm_password']) ? $_POST['confirm_password'] : '';

if (empty($username) || empty($email) || empty($business_name) || empty($role) || empty($password) || empty($confirm_password)) {
    $flag['message'] = "Missing parameters";
} elseif ($password !== $confirm_password) {
    $flag['message'] = "Passwords do not match";
} else {
    // Check if the business name exists with the same role more than once
    $check_query = "SELECT * FROM users WHERE business_name = ? AND role = ?";
    $check_stmt = mysqli_prepare($con, $check_query);

    if ($check_stmt) {
        mysqli_stmt_bind_param($check_stmt, "ss", $business_name, $role);
        mysqli_stmt_execute($check_stmt);
        $result = mysqli_stmt_get_result($check_stmt);

        if (mysqli_num_rows($result) >= 2) {
            $flag['message'] = "Business name already exists with the same role twice";
        } else {
            // Check if the business name already exists
            $business_check_query = "SELECT store_id FROM users WHERE business_name = ?";
            $business_check_stmt = mysqli_prepare($con, $business_check_query);

            if ($business_check_stmt) {
                mysqli_stmt_bind_param($business_check_stmt, "s", $business_name);
                mysqli_stmt_execute($business_check_stmt);
                $business_result = mysqli_stmt_get_result($business_check_stmt);

                if (mysqli_num_rows($business_result) > 0) {
                    $row = mysqli_fetch_assoc($business_result);
                    $store_id = $row['store_id'];
                } else {
                    // Get the last store_id and increment it
                    $last_store_query = "SELECT store_id FROM users ORDER BY store_id DESC LIMIT 1";
                    $last_store_result = mysqli_query($con, $last_store_query);
                    if (mysqli_num_rows($last_store_result) > 0) {
                        $last_store_row = mysqli_fetch_assoc($last_store_result);
                        $last_store_id = $last_store_row['store_id'];
                        $store_id = 'st' . (intval(substr($last_store_id, 2)) + 1);
                    } else {
                        $store_id = 'st2024';
                    }
                }

                $created_at = date('Y-m-d H:i:s');
                $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
                $insert_query = "INSERT INTO users (username, email, business_name, role, password, created_at, store_id) VALUES (?, ?, ?, ?, ?, ?, ?)";
                $insert_stmt = mysqli_prepare($con, $insert_query);

                if ($insert_stmt) {
                    mysqli_stmt_bind_param($insert_stmt, "sssssss", $username, $email, $business_name, $role, $hashedPassword, $created_at, $store_id);

                    if (mysqli_stmt_execute($insert_stmt)) {
                        $flag['success'] = 1;
                        $flag['message'] = "Registration successful";
                    } else {
                        $flag['message'] = "Error: " . mysqli_error($con);
                    }

                    mysqli_stmt_close($insert_stmt);
                } else {
                    $flag['message'] = "Error preparing insert statement: " . mysqli_error($con);
                }
            } else {
                $flag['message'] = "Error preparing business check statement: " . mysqli_error($con);
            }

            mysqli_stmt_close($business_check_stmt);
        }

        mysqli_stmt_close($check_stmt);
    } else {
        $flag['message'] = "Error preparing check statement: " . mysqli_error($con);
    }
}

echo json_encode($flag);
mysqli_close($con);
?>







